@@ -569,13 +569,13 @@ def initialize(doc_filepath, debug_output=None):
         pass
 
     if print_feed:
-        print '@@@@@@@@@@@@@@@@@@@@@@@@@ dd FEED @@@@@@@@@@@@@@@@@@@@@@@@@'
+        print '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ dd feed @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@'
     global driven_doc
     driven_doc = DrivenDoc()
     root_dir, basename = os.path.split(doc_filepath)
     feed_file(driven_doc, doc_filepath, root_dir, line_feed, file_feed, print_feed, rcrsn_lvl=0)
     if print_feed:
-        print '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@'
+        print '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@'
 
 
 link_to_file_pattern = '(^%# (\w+.*)|^#### ((config|predict|response|runtime|status)/\w+.*))'
@@ -617,7 +617,7 @@ def feed_file(driven_doc, filepath, root_dir, line_feed, file_feed, print_feed,
 
 def feed_line(driven_doc, line, from_filekey, line_feed, print_feed, rcrsn_lvl):
     if print_feed:
-        print ' '*(4*rcrsn_lvl)+'| '+line.rstrip()
+        print ' '*(4*rcrsn_lvl)+'|   '+line.rstrip()
     if line_feed:
         print 'docdriven:    '+line.rstrip()
     driven_doc.feed_line(line, from_filekey)
